==> zio-aws-dataexchange_2.13-5.17.129.2-sources.jar: zio/aws/dataexchange/model/DeleteDataSetRequest.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteDataSetRequest(dataSetId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.DeleteDataSetRequest = {
    import DeleteDataSetRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.DeleteDataSetRequest
      .builder()
      .dataSetId(__string.unwrap(dataSetId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.DeleteDataSetRequest.ReadOnly =
    zio.aws.dataexchange.model.DeleteDataSetRequest.wrap(buildAwsValue())
}
object DeleteDataSetRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.DeleteDataSetRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.DeleteDataSetRequest =
      zio.aws.dataexchange.model.DeleteDataSetRequest(dataSetId)
    def dataSetId: __string
    def getDataSetId: ZIO[Any, Nothing, __string] = ZIO.succeed(dataSetId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.DeleteDataSetRequest
  ) extends zio.aws.dataexchange.model.DeleteDataSetRequest.ReadOnly {
    override val dataSetId: __string =
      zio.aws.dataexchange.model.primitives.__string(impl.dataSetId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.DeleteDataSetRequest
  ): zio.aws.dataexchange.model.DeleteDataSetRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-dataexchange_2.13-5.17.155.2-sources.jar: zio/aws/dataexchange/model/DeleteDataSetRequest.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteDataSetRequest(dataSetId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.DeleteDataSetRequest = {
    import DeleteDataSetRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.DeleteDataSetRequest
      .builder()
      .dataSetId(dataSetId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.DeleteDataSetRequest.ReadOnly =
    zio.aws.dataexchange.model.DeleteDataSetRequest.wrap(buildAwsValue())
}
object DeleteDataSetRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.DeleteDataSetRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.DeleteDataSetRequest =
      zio.aws.dataexchange.model.DeleteDataSetRequest(dataSetId)
    def dataSetId: __string
    def getDataSetId: ZIO[Any, Nothing, __string] = ZIO.succeed(dataSetId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.DeleteDataSetRequest
  ) extends zio.aws.dataexchange.model.DeleteDataSetRequest.ReadOnly {
    override val dataSetId: __string = impl.dataSetId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.DeleteDataSetRequest
  ): zio.aws.dataexchange.model.DeleteDataSetRequest.ReadOnly = new Wrapper(
    impl
  )
}
